#
# spec file for package libxlsxwriter
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname libxlsxwriter7

Name:           libxlsxwriter
Version:        1.1.9
Release:        1.2
Summary:        A C library for creating Excel XLSX files
License:        BSD-2-Clause
Group:          Development/Libraries/C and C++
URL:            https://github.com/jmcnamara/libxlsxwriter
Source:         %{url}/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig(minizip)
BuildRequires:  pkgconfig(zlib)
# Tests
BuildRequires:  python3-pytest

%description
A C library for creating Excel XLSX files.

%package -n %{libname}
Summary:        A C library for creating Excel XLSX files
Group:          System/Libraries

%description -n %{libname}
Libxlsxwriter is a C library for creating Excel XLSX files.

This package holds the shared library files.

%package devel
Summary:        Headers for libxlsxwriter
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description devel
Libxlsxwriter is a C library for creating Excel XLSX files.

This package holds the development files.

%prep
%autosetup -p1

%build
%cmake -DUSE_SYSTEM_MINIZIP=ON -DBUILD_TESTS=ON
%cmake_build

%install
%cmake_install

%check
%ifnarch s390x
%ctest
%endif

%post   -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license License.txt
%{_libdir}/libxlsxwriter.so.*

%files devel
%license License.txt
%doc Changes.txt Readme.md CONTRIBUTING.md
%{_includedir}/xlsxwriter.h
%{_includedir}/xlsxwriter/
%{_libdir}/pkgconfig/xlsxwriter.pc
%{_libdir}/libxlsxwriter.so

%changelog
* Fri Oct 25 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to version 1.1.9:
  * CMake: Check for third party libraries using pkgconfig
  * Fix minor pointer/value error in lxw_name_to_row() and
    lxw_name_to_col() utility functions.
* Thu Aug  1 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to version 1.1.8:
  * Added support for embedding images into worksheets with
    worksheet_embed_image().
  * Bump .so version to 7
  Fixes
  * Failure on 32bit architectures
  * workbook_validate_sheet_name buffer-overflow
  * workbook_add_worksheet does not return a reasonable worksheet
  * workbook_define_name stack-buffer-underflow
  * workbook_close stack-buffer-overflow
  * _store_array_formula heap-buffer-overflow
  * worksheet_set_selection stack-buffer-overflow
* Sun Apr  7 2024 Joshua Smith <smolsheep@opensuse.org>
- Remove find_minizip.patch -- merged upstream
- Update URL and source name
- Update to version 1.1.7:
  * Bump .so version to 6
  * Added quote_prefix format property
  * Added support for signed VBA projects
  * Fix worksheet password hashing algorithm for long passwords
    Replace/fix the worksheet protection password algorithm so that
    is works correctly for strings over 24 chars
  * Fix cmake minizip version check
  * Fix for buffer overflow with utf-8 strings in data validation
  * Fix for range in text type conditional format
  * Fix 32bit multiply with overflow issue for images
  * Added support for building Zig library
* Fri Feb 23 2024 Joshua Smith <jsmithfpv@gmail.com>
- Add find_minizip.patch -- upstream patches to fix usage of system
  libraries.
- Switch to cmake, fixing 32bit builds.
* Fri Jul 14 2023 Joshua Smith <jsmithfpv@gmail.com>
- Remove statically linked library
* Thu Jul 13 2023 Jan Engelhardt <jengelh@inai.de>
- Switch to 1.1.5's fixated tarball with a Source URL
- Edit package metadata
* Mon Mar 27 2023 Joshua Smith <jsmithfpv@gmail.com>
- Update to version 1.1.5:
  * Ignore openssl3 deprecation warnings
  * Minor doc fix.
  * Fix minizip compile warnings.
  * Update docs/example for lambda function.
  * Minor doc/example fix.
  * Fix top/bottom10 conditional format for values other than 10.
  * Added memory buffer example to the docs.
  * Improve buffer support.
  * Add memory buffer support
* Mon Nov 28 2022 Joshua Smith <jsmithfpv@gmail.com>
- Updated to 1.1.4:
  Added:
  * New support for worksheet tables.
  * Macro buttons can be added to worksheets
  * New support for autofilter rules.
  * Description/Alt Text options for charts.
  * Supports Excel365 dynamic arrays
* Fri Feb 19 2021 Duncan Mac-Vicar <dmacvicar@suse.de>
- Make devel package require the shared library
* Sat Feb 16 2019 Duncan Mac-Vicar <dmacvicar@suse.de>
- Initial package for 0.8.5
